PendingTransactionDescription class

Constructors

PendingTransactionDescription({required int amount, required int fee, required String hash, required String hex, required String txKey, required String multisigSignData, required int pointerAddress})

Properties

amount int
final
fee int
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
hex String
final
multisigSignData String
final
pointerAddress int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txKey String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited