TransactionInfoRow class
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - amount ↔ int
-
getter/setter pair
- blockHeight ↔ int
-
getter/setter pair
- confirmations ↔ int
-
getter/setter pair
- datetime ↔ int
-
getter/setter pair
- direction ↔ int
-
getter/setter pair
- fee ↔ int
-
getter/setter pair
-
hash
↔ Pointer<
Utf8> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPending ↔ int
-
getter/setter pair
-
paymentId
↔ Pointer<
Utf8> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subaddrAccount ↔ int
-
getter/setter pair
- subaddrIndex ↔ int
-
getter/setter pair
Methods
-
getAmount(
) → int -
getDatetime(
) → int -
getHash(
) → String -
getIsPending(
) → bool -
getPaymentId(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited