ExternPendingTransactionRaw class

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
amount int
getter/setter pair
fee int
getter/setter pair
hash Pointer<Char>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hex Pointer<Char>
getter/setter pair
monero_transaction_handle int
getter/setter pair
multisig_sign_data Pointer<Char>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tx_key Pointer<Char>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited